#include "assets.h"
#include "camera.h"
#include "debug.h"
#include "input.h"
#include "physics_entity.h"
#include "physics_world.h"
#include "program.h"
#include "rigidbody.h"
#include "spritesheet.h"
#include "sprite.h"
#include "tilemap.h"
#include "player.h"
#include <SDL2/SDL_scancode.h>
#include <assert.h>

static Player* player = NULL;
static Level* level = NULL;

static
void toggle_info_key(int down) {
    if(down) {
        g_debug_log_lvl = (g_debug_log_lvl + 1) % 4;
    }
}

static
void play() {
    input_add_key_action(SDL_SCANCODE_F1, &toggle_info_key);
    g_camera.fov = 40;

    player = player_new();
    player_spawn(player, (Vector){8.25f, 15.f});

    level = level_load("level_0");
}

static
void tick() {
    g_camera.transform.position = player->transform.position;
}

static
void draw() {
    level_draw(level);
    sprite_entity_draw(Player_as_SpriteEntity(player));
    physics_entity_debug_draw(Player_as_PhysicsEntity(player));
}

int main(int argc, char* argv[]) {
    struct ProgramSettings config = {
        .target_fps = 120,
        .title = "fencer",
        .view_resolution = {1920, 1080},
        .on_play = &play,
        .on_tick = &tick,
        .on_draw = &draw
    };
    return program_run(&config);
}
